

# General Information:

ngfp aka new gfpoken aka gfpoken-in-python, is a Python 3 adaptation of the gfpoken program using pyglet and GTK3.  ngfp is a puzzle game where you place mirrors to interact with marbles rolling through a grid.  The complexity and size of the game can be adjusted.  Some games may have more than one solution but they will all count as winning games.  Have fun!


# New Contributions

  - check TODO or ask to make sure efforts are not duplicated

  - new code will be licensed under Apache-2.0
    - attribution will be to "Name" <email@address>

  - to make spacing consistent use:

      to see what the changes would look like:

     $ autopep8 . --recursive --select=E101,E121 --diff

      to make the changes:

     $ autopep8 . --recursive --select=E101,E121 --in-place


# Previous Artwork and Manual Page

  From gfpoken version 1-2 the following things were used (see AUTHORS for the list of files and their copyrights and licensing):

  - artwork which was rescaled to 64 pixels

  - the man page was adapted/edited


